Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CreateMintTxn ¶
func CreateMintTxn(nonceInfo nonce.NonceInfo, symbol string, amount string, recipient string, publicKeyBase58 string, privateKeyBase58 string, feeID string, feeAmountParts string) (*pb.MintTXN, error)
CreateMintTxn creates a MintTXN protobuf message for minting new tokens to a specific address.
Parameters: - useIndexer: true for data grab from indexer, false for validator - symbol: contract symbol to mint (example: $ZRA+0000) - amount: amount to mint, in full coins (as a string, not parts) - recipient: Base58-encoded address to receive the minted tokens - publicKeyBase58: Base58-encoded public key of the minting authority - privateKeyBase58: Base58-encoded private key corresponding to the above public key - feeID: fee id for the mint operation (example: $ZRA+0000) - feeAmountParts: fee amount in *parts* (example: 1000000000 = 1 ZRA)
Returns: - *pb.MintTXN: the constructed and signed MintTXN - error: if any step in construction or signing fails
Types ¶
This section is empty.